@@ -175,7 +175,7 @@ interface_base_finalize( NAIContextInterface *klass )
  *
  * Returns: %TRUE if this @a and @b are equal, %FALSE else.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 gboolean
 na_icontext_are_equal( const NAIContext *a, const NAIContext *b )
@@ -324,7 +324,7 @@ na_icontext_check_mimetypes( const NAIContext *context )
  *
  * Copy specific data from @source to @context.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 void
 na_icontext_copy( NAIContext *context, const NAIContext *source )
@@ -1008,6 +1008,7 @@ is_candidate_for_schemes( const NAIContext *object, guint target, GList *files )
 		na_core_utils_slist_free( schemes );
 	}
 
+	g_debug( "%s: ok=%s", thisfn, ok ? "True":"False" );
 	return( ok );
 }
 
@@ -1018,7 +1019,7 @@ is_compatible_scheme( const gchar *pattern, const gchar *scheme )
 
 	compatible = FALSE;
 
-	if( strcmp( pattern, "*" )){
+	if( strcmp( pattern, "*" ) == 0 ){
 		compatible = TRUE;
 	} else {
 		compatible = ( strcmp( pattern, scheme ) == 0 );
