@@ -34,22 +34,16 @@
 
 #include <string.h>
 
-#include <core/na-iprefs.h>
+#include <core/na-gtk-utils.h>
 #include <core/na-updater.h>
 
 #include "base-gtk-utils.h"
-#include "nact-application.h"
 
 #define NACT_PROP_TOGGLE_BUTTON				"nact-prop-toggle-button"
 #define NACT_PROP_TOGGLE_HANDLER			"nact-prop-toggle-handler"
 #define NACT_PROP_TOGGLE_USER_DATA			"nact-prop-toggle-user-data"
 
 #define DEFAULT_WIDTH		22
-#define DEFAULT_HEIGHT		22
-
-static void        int_list_to_position( const BaseWindow *window, GList *list, gint *x, gint *y, gint *width, gint *height );
-static GList      *position_to_int_list( const BaseWindow *window, gint x, gint y, gint width, gint height );
-static void        free_int_list( GList *list );
 
 /**
  * base_gtk_utils_position_window:
@@ -63,42 +57,15 @@ static void        free_int_list( GList *list );
 void
 base_gtk_utils_restore_window_position( const BaseWindow *window, const gchar *wsp_name )
 {
-	static const gchar *thisfn = "base_gtk_utils_restore_window_position";
 	GtkWindow *toplevel;
-	GList *list;
-	gint x=0, y=0, width=0, height=0;
-	GdkDisplay *display;
-	GdkScreen *screen;
-	gint screen_width, screen_height;
 
 	g_return_if_fail( BASE_IS_WINDOW( window ));
 	g_return_if_fail( wsp_name && strlen( wsp_name ));
 
 	toplevel = base_window_get_gtk_toplevel( window );
+	g_return_if_fail( GTK_IS_WINDOW( toplevel ));
 
-	g_debug( "%s: window=%p (%s), toplevel=%p (%s), wsp_name=%s",
-			thisfn, ( void * ) window, G_OBJECT_TYPE_NAME( window ),
-			( void * ) toplevel, G_OBJECT_TYPE_NAME( toplevel ), wsp_name );
-
-	list = na_settings_get_uint_list( wsp_name, NULL, NULL );
-
-	if( list ){
-		int_list_to_position( window, list, &x, &y, &width, &height );
-		g_debug( "%s: wsp_name=%s, x=%d, y=%d, width=%d, height=%d", thisfn, wsp_name, x, y, width, height );
-		free_int_list( list );
-	}
-
-	if( width > 0 && height > 0 ){
-		display = gdk_display_get_default();
-		screen = gdk_display_get_screen( display, 0 );
-		screen_width = gdk_screen_get_width( screen );
-		screen_height = gdk_screen_get_height( screen );
-
-		if(( x+width < screen_width ) && ( y+height < screen_height )){
-			gtk_window_move( toplevel, x, y );
-			gtk_window_resize( toplevel, width, height );
-		}
-	}
+	na_gtk_utils_restore_window_position( toplevel, wsp_name );
 }
 
 /**
@@ -111,10 +78,7 @@ base_gtk_utils_restore_window_position( const BaseWindow *window, const gchar *w
 void
 base_gtk_utils_save_window_position( const BaseWindow *window, const gchar *wsp_name )
 {
-	static const gchar *thisfn = "base_gtk_utils_save_window_position";
 	GtkWindow *toplevel;
-	gint x, y, width, height;
-	GList *list;
 
 	g_return_if_fail( BASE_IS_WINDOW( window ));
 	g_return_if_fail( wsp_name && strlen( wsp_name ));
@@ -122,67 +86,7 @@ base_gtk_utils_save_window_position( const BaseWindow *window, const gchar *wsp_
 	toplevel = base_window_get_gtk_toplevel( window );
 	g_return_if_fail( GTK_IS_WINDOW( toplevel ));
 
-	gtk_window_get_position( toplevel, &x, &y );
-	gtk_window_get_size( toplevel, &width, &height );
-	g_debug( "%s: wsp_name=%s, x=%d, y=%d, width=%d, height=%d", thisfn, wsp_name, x, y, width, height );
-
-	list = position_to_int_list( window, x, y, width, height );
-	na_settings_set_uint_list( wsp_name, list );
-	free_int_list( list );
-}
-
-/*
- * extract the position of the window from the list of unsigned integers
- */
-static void
-int_list_to_position( const BaseWindow *window, GList *list, gint *x, gint *y, gint *width, gint *height )
-{
-	GList *it;
-	int i;
-
-	g_assert( x );
-	g_assert( y );
-	g_assert( width );
-	g_assert( height );
-
-	for( it=list, i=0 ; it ; it=it->next, i+=1 ){
-		switch( i ){
-			case 0:
-				*x = GPOINTER_TO_UINT( it->data );
-				break;
-			case 1:
-				*y = GPOINTER_TO_UINT( it->data );
-				break;
-			case 2:
-				*width = GPOINTER_TO_UINT( it->data );
-				break;
-			case 3:
-				*height = GPOINTER_TO_UINT( it->data );
-				break;
-		}
-	}
-}
-
-static GList *
-position_to_int_list( const BaseWindow *window, gint x, gint y, gint width, gint height )
-{
-	GList *list = NULL;
-
-	list = g_list_append( list, GUINT_TO_POINTER( x ));
-	list = g_list_append( list, GUINT_TO_POINTER( y ));
-	list = g_list_append( list, GUINT_TO_POINTER( width ));
-	list = g_list_append( list, GUINT_TO_POINTER( height ));
-
-	return( list );
-}
-
-/*
- * free the list of int
- */
-static void
-free_int_list( GList *list )
-{
-	g_list_free( list );
+	na_gtk_utils_save_window_position( toplevel, wsp_name );
 }
 
 /**
@@ -574,16 +478,12 @@ base_gtk_utils_select_file_with_preview( BaseWindow *window,
 				GtkWidget *entry, const gchar *entry_name,
 				GCallback update_preview_cb )
 {
-	NactApplication *application;
-	NAUpdater *updater;
 	GtkWindow *toplevel;
 	GtkWidget *dialog;
 	const gchar *text;
 	gchar *filename, *uri;
 	GtkWidget *preview;
 
-	application = NACT_APPLICATION( base_window_get_application( window ));
-	updater = nact_application_get_updater( application );
 	toplevel = base_window_get_gtk_toplevel( window );
 
 	dialog = gtk_file_chooser_dialog_new(
@@ -655,15 +555,11 @@ base_gtk_utils_select_dir( BaseWindow *window,
 				const gchar *title, const gchar *wsp_name,
 				GtkWidget *entry, const gchar *entry_name )
 {
-	NactApplication *application;
-	NAUpdater *updater;
 	GtkWindow *toplevel;
 	GtkWidget *dialog;
 	const gchar *text;
 	gchar *dir, *uri;
 
-	application = NACT_APPLICATION( base_window_get_application( window ));
-	updater = nact_application_get_updater( application );
 	toplevel = base_window_get_gtk_toplevel( window );
 
 	dialog = gtk_file_chooser_dialog_new(
