@@ -363,6 +363,10 @@ on_base_initialize_gtk_toplevel( NactPreferencesEditor *editor, GtkDialog *tople
 
 		listview = GTK_TREE_VIEW( base_window_get_widget( BASE_WINDOW( editor ), "ProvidersTreeView" ));
 		nact_providers_list_create_model( listview );
+
+#if !GTK_CHECK_VERSION( 2,22,0 )
+		gtk_dialog_set_has_separator( toplevel, FALSE );
+#endif
 	}
 }
 
@@ -703,14 +707,12 @@ desktop_create_model( NactPreferencesEditor *editor )
 static void
 desktop_setup( NactPreferencesEditor *editor )
 {
-	gboolean editable;
 	GtkWidget *combo;
 	const NADesktopEnv *desktops;
 	guint i;
 	gint found;
 
 	editor->private->desktop = na_settings_get_string( NA_IPREFS_DESKTOP_ENVIRONMENT, NULL, &editor->private->desktop_mandatory );
-	editable = !editor->private->preferences_locked && !editor->private->desktop_mandatory;
 
 	combo = base_window_get_widget( BASE_WINDOW( editor ), "DesktopComboBox" );
 	found = -1;
